% Auto-generated chapter 16 for ibnmajah
% Hadiths in this chapter: 53

\hadithdefcmd{ibnmajah}{2436}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، حَدَّثَنِي الأَسْوَدُ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اشْتَرَى مِنْ يَهُودِيٍّ طَعَامًا إِلَى أَجَلٍ وَأَرْهَنَهُ دِرْعَهُ ‏.‏\hadithno{2436}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aisha that :the Messenger of Allah (ﷺ) bought some food from a Jew with payment to be made later, and he pawned his armor for that}}
\hadithdefcmd{ibnmajah}{2437}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنِي أَبِي، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ لَقَدْ رَهَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِرْعَهُ عِنْدَ يَهُودِيٍّ بِالْمَدِينَةِ فَأَخَذَ لأَهْلِهِ مِنْهُ شَعِيرًا ‏.‏\hadithno{2437}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:“The Messenger of Allah (ﷺ) pawned his armor to a jew in Al-Madinah, and took barely for his family in return.”}}
\hadithdefcmd{ibnmajah}{2438}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ عَبْدِ الْحَمِيدِ بْنِ بَهْرَامَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تُوُفِّيَ وَدِرْعُهُ مَرْهُونَةٌ عِنْدَ يَهُودِيٍّ بِطَعَامٍ ‏.‏\hadithno{2438}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Asma' bin Yazid that:the Prophet (ﷺ) died while his armor was pawned to a Jew for food}}
\hadithdefcmd{ibnmajah}{2439}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا ثَابِتُ بْنُ يَزِيدَ، حَدَّثَنَا هِلاَلُ بْنُ خَبَّابٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَاتَ وَدِرْعُهُ رَهْنٌ عِنْدَ يَهُودِيٍّ بِثَلاَثِينَ صَاعًا مِنْ شَعِيرٍ ‏.‏\hadithno{2439}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:the Messenger of Allah (ﷺ) died while his armor was pawned to a Jew for thirty Sa’s of barley.' ”}}
\hadithdefcmd{ibnmajah}{2440}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ زَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الظَّهْرُ يُرْكَبُ إِذَا كَانَ مَرْهُونًا وَلَبَنُ الدَّرِّ يُشْرَبُ إِذَا كَانَ مَرْهُونًا وَعَلَى الَّذِي يَرْكَبُ وَيَشْرَبُ نَفَقَتُهُ ‏"‏ ‏.‏\hadithno{2440}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“A mount may be ridden when it is pawned, and its milk may be drunk when it is pawned, but the one who rides it or milks it must pay for its upkeep.' ”}}
\hadithdefcmd{ibnmajah}{2441}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُخْتَارِ، عَنْ إِسْحَاقَ بْنِ رَاشِدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَغْلَقُ الرَّهْنُ ‏"‏ ‏.‏\hadithno{2441}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Do not forfeit items held in pledge.”}}
\hadithdefcmd{ibnmajah}{2442}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ أَنَا خَصْمُهُمْ يَوْمَ الْقِيَامَةِ وَمَنْ كُنْتُ خَصْمَهُ خَصَمْتُهُ يَوْمَ الْقِيَامَةِ رَجُلٌ أَعْطَى بِي ثُمَّ غَدَرَ وَرَجُلٌ بَاعَ حُرًّا فَأَكَلَ ثَمَنَهُ وَرَجُلٌ اسْتَأْجَرَ أَجِيرًا فَاسْتَوْفَى مِنْهُ وَلَمْ يُوفِهِ أَجْرَهُ ‏"‏ ‏.‏\hadithno{2442}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:(Allah (SWT) says:) “I am the opponent of three on the Day of Resurrection, and if I am someone's opponent I will defeat him: A man who makes promises in My Name, then proves treacherous; a man who sells a free man and consumes his price; and a man who hires a worker, makes use to him, then does not give him his wages.”}}
\hadithdefcmd{ibnmajah}{2443}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا وَهْبُ بْنُ سَعِيدِ بْنِ عَطِيَّةَ السُّلَمِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعْطُوا الأَجِيرَ أَجْرَهُ قَبْلَ أَنْ يَجِفَّ عَرَقُهُ ‏"‏ ‏.‏\hadithno{2443}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Messenger of Allah (ﷺ) said:“Give the worker his wages before his sweat dries.”}}
\hadithdefcmd{ibnmajah}{2444}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ مَسْلَمَةَ بْنِ عُلَىٍّ، عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ، عَنِ الْحَارِثِ بْنِ يَزِيدَ، عَنْ عُلَىِّ بْنِ رَبَاحٍ، قَالَ سَمِعْتُ عُتْبَةَ بْنَ النُّدَّرِ، يَقُولُ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَرَأَ طسم حَتَّى إِذَا بَلَغَ قِصَّةَ مُوسَى قَالَ ‏ "‏ إِنَّ مُوسَى صلى الله عليه وسلم أَجَّرَ نَفْسَهُ ثَمَانِيَ سِنِينَ أَوْ عَشْرًا عَلَى عِفَّةِ فَرْجِهِ وَطَعَامِ بَطْنِهِ ‏"‏ ‏.‏\hadithno{2444}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali bin Rabah said:“I heard 'Utbah bin Nuddar say: 'We were with the Messenger of Allah (ﷺ) and he recited Ta-Sin. When he reached the story of Musa, he said: 'Musa (A.S) hired himself out for eight years, or ten, in return for his chastity and food in his stomach.' ”}}
\hadithdefcmd{ibnmajah}{2445}{حَدَّثَنَا أَبُو عُمَرَ، حَفْصُ بْنُ عَمْرٍو حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ نَشَأْتُ يَتِيمًا وَهَاجَرْتُ مِسْكِينًا وَكُنْتُ أَجِيرًا لاِبْنَةِ غَزْوَانَ بِطَعَامِ بَطْنِي وَعُقْبَةِ رِجْلِي أَحْطِبْ لَهُمْ إِذَا نَزَلُوا وَأَحْدُو لَهُمْ إِذَا رَكِبُوا فَالْحَمْدُ لِلَّهِ الَّذِي جَعَلَ الدِّينَ قِوَامًا وَجَعَلَ أَبَا هُرَيْرَةَ إِمَامًا ‏.‏\hadithno{2445}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Salim bin Hayyan said:I heard Abu Hurairah say: “I grew up an orphan, and I emigrated as a poor man, and I was hired by the daughter of Ghazwan in return for food and a turn riding the camel. I would gather firewood for them when they stopped to camp and urge their camels along for them by singing when they rode. Praise is to Allah (SWT) who has caused His religion to prevail and has made Abu Hurairah an Imam.”}}
\hadithdefcmd{ibnmajah}{2446}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ حَنَشٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَصَابَ نَبِيَّ اللَّهِ صلى الله عليه وسلم خَصَاصَةٌ فَبَلَغَ ذَلِكَ عَلِيًّا فَخَرَجَ يَلْتَمِسُ عَمَلاً يُصِيبُ فِيهِ شَيْئًا لِيُغِيثَ بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَتَى بُسْتَانًا لِرَجُلٍ مِنَ الْيَهُودِ فَاسْتَقَى لَهُ سَبْعَةَ عَشَرَ دَلْوًا كُلُّ دَلْوٍ بِتَمْرَةٍ فَخَيَّرَهُ الْيَهُودِيُّ مِنْ تَمْرِهِ سَبْعَ عَشَرَةَ عَجْوَةً فَجَاءَ بِهَا إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2446}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:“The Prophet (ﷺ) was in need of food, and news of that reached 'Ali. He went out seeking work so that he could earn something to give to the Messenger of Allah (ﷺ). He came to a garden belonging to a Jewish man, and he drew seventeen buckets of water for him, each bucket for a date. The Jew gave him the option to take seventeen of his 'Ajwah dates (a high quality of dates) and he brought them to the Prophet of Allah (ﷺ).”}}
\hadithdefcmd{ibnmajah}{2447}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَيَّةَ، عَنْ عَلِيٍّ، قَالَ كُنْتُ أَدْلُو الدَّلْوَ بِتَمْرَةٍ وَأَشْتَرِطُ أَنَّهَا جَلْدَةٌ ‏.‏\hadithno{2447}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:“I used to draw water, one bucket for a date, and I stipulated that they should be good quality, dried dates.”}}
\hadithdefcmd{ibnmajah}{2448}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، عَنْ جَدِّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ مِنَ الأَنْصَارِ فَقَالَ يَا رَسُولَ اللَّهِ مَا لِي أَرَى لَوْنَكَ مُنْكَفِئًا ‏.‏ قَالَ ‏ "‏ الْخَمْصُ ‏"‏ ‏.‏ فَانْطَلَقَ الأَنْصَارِيُّ إِلَى رَحْلِهِ فَلَمْ يَجِدْ فِي رَحْلِهِ شَيْئًا فَخَرَجَ يَطْلُبُ فَإِذَا هُوَ بِيَهُودِيٍّ يَسْقِي نَخْلاً فَقَالَ الأَنْصَارِيُّ لِلْيَهُودِيِّ أَسْقِي نَخْلَكَ قَالَ نَعَمْ ‏.‏ قَالَ كُلُّ دَلْوٍ بِتَمْرَةٍ ‏.‏ وَاشْتَرَطَ الأَنْصَارِيُّ أَنْ لاَ يَأْخُذَ خَدِرَةً وَلاَ تَارِزَةً وَلاَ حَشَفَةً وَلاَ يَأْخُذَ إِلاَّ جَلْدَةً ‏.‏ فَاسْتَقَى بِنَحْوٍ مِنْ صَاعَيْنِ فَجَاءَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2448}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“A man from among the Ansar Came and said: 'O Messenger of Allah (ﷺ), why do I see that your color has changed?' He said: 'Hunger.' So the Ansari went to his dwelling, but he did not find anything in his dwelling, so he went out looking, and he found a Jew watering his date-palm trees. The Ansari stipulated that he would not take any dates that were black (rotten), hard and dried out or inferior, and he would only take good quality dates. He earned nearly two Sa's (of dates), and he brought it to the Prophet (ﷺ).”}}
\hadithdefcmd{ibnmajah}{2449}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ طَارِقِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ ‏.‏ وَقَالَ ‏ "‏ إِنَّمَا يَزْرَعُ ثَلاَثَةٌ رَجُلٌ لَهُ أَرْضٌ فَهُوَ يَزْرَعُهَا وَرَجُلٌ مُنِحَ أَرْضًا فَهُوَ يَزْرَعُ مَا مُنِحَ وَرَجُلٌ اسْتَكْرَى أَرْضًا بِذَهَبٍ أَوْ فِضَّةٍ ‏"‏ ‏.‏\hadithno{2449}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Rafi 'bin Khadji said:“The Messenger of Allah (ﷺ) forbade Muhaqalah and Muzabanah, and said: 'Only three may cultivate: A man who has land which he cultivates a man who was given some land and cultivates what he was given; and a man who takes land on lease for gold or silver.' ”}}
\hadithdefcmd{ibnmajah}{2450}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ كُنَّا نُخَابِرُ وَلاَ نَرَى بِذَلِكَ بَأْسًا حَتَّى سَمِعْنَا رَافِعَ بْنَ خَدِيجٍ يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْهُ ‏.‏ فَتَرَكْنَاهُ لِقَوْلِهِ ‏.‏\hadithno{2450}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Amr bin Dinar said:“I heard Ibn 'Umar say: 'We used to lend land for cultivation in return for a share of the harvest, and we did not see anything wrong with that, until we heard Rafi' bin Khadij say: “The Messenger of Allah (ﷺ) forbade it.” Then we stopped because of what he said.' ”}}
\hadithdefcmd{ibnmajah}{2451}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي عَطَاءٌ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَانَتْ لِرِجَالٍ مِنَّا فُضُولُ أَرَضِينَ يُؤَاجِرُونَهَا عَلَى الثُّلُثِ وَالرُّبُعِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ فُضُولُ أَرَضِينَ فَلْيَزْرَعْهَا أَوْ لِيُزْرِعْهَا أَخَاهُ فَإِنْ أَبَى فَلْيُمْسِكْ أَرْضَهُ ‏"‏ ‏.‏\hadithno{2451}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ata' said:“I heard Jabir bin 'Abdullah say: Some men among us had extra land which they would rent out for one third or one quarter (of the crop). The Prophet (ﷺ) said: “Whoever has extra land, let him cultivate it (himself) or let him give it to his brother (for free, to cultivate it), and if he does not want to do that, let him keep his land.”}}
\hadithdefcmd{ibnmajah}{2452}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ لِيَمْنَحْهَا أَخَاهُ فَإِنْ أَبَى فَلْيُمْسِكْ أَرْضَهُ ‏"‏ ‏.‏\hadithno{2452}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever has land, let him cultivate it (himself) or let him give it to his brother (for free, to cultivate it), and if he does not want to do that, let him keep his land.”}}
\hadithdefcmd{ibnmajah}{2453}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَأَبُو أُسَامَةَ وَمُحَمَّدُ بْنُ عُبَيْدٍ عَنْ عُبَيْدِ اللَّهِ، - أَوْ قَالَ عَبْدِ اللَّهِ بْنِ عُمَرَ - عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يُكْرِي أَرْضًا لَهُ مَزَارِعًا فَأَتَاهُ إِنْسَانٌ فَأَخْبَرَهُ عَنْ رَافِعِ بْنِ خَدِيجٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الْمَزَارِعِ فَذَهَبَ ابْنُ عُمَرَ وَذَهَبْتُ مَعَهُ حَتَّى أَتَاهُ بِالْبَلاَطِ فَسَأَلَهُ عَنْ ذَلِكَ فَأَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الْمَزَارِعِ فَتَرَكَ عَبْدُ اللَّهِ كِرَاءَهَا ‏.‏\hadithno{2453}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:he used to lease out some land that belonged to him, for cultivation. Then someone came to him and told him that Rafi' bin Khadij said that the Messenger of Allah (ﷺ) had forbidden leasing out land for cultivation. Ibn 'Umar went, and I went with him, until he met him in Balat, and asked him about that, and he told him that the Messenger of Allah (ﷺ) had forbidden leasing out land for cultivation. So 'Abdullah stopped lessening out land}}
\hadithdefcmd{ibnmajah}{2454}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا ضَمْرَةُ بْنُ رَبِيعَةَ، عَنِ ابْنِ شَوْذَبٍ، عَنْ مَطَرٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ لِيُزْرِعْهَا وَلاَ يُؤَاجِرْهَا ‏"‏ ‏.‏\hadithno{2454}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:“The Messenger of Allah (ﷺ) addressed us and said: 'Whoever has land, let him cultivate it or allow someone else to cultivate it, and not rent it out.' ”}}
\hadithdefcmd{ibnmajah}{2455}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُطَرِّفُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَالِكٌ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِي سُفْيَانَ، - مَوْلَى ابْنِ أَبِي أَحْمَدَ - أَنَّهُ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ ‏.‏ وَالْمُحَاقَلَةُ اسْتِكْرَاءُ الأَرْضِ ‏.‏\hadithno{2455}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sufyan, the freed slave of Ibn Abu Ahmad, that he told him that he heard Abu Sa'eed Al-Khudri say:“The Messenger of Allah (ﷺ) forbade Muhaqlah.” (Sahih)Muhaqlah means leasing out land}}
\hadithdefcmd{ibnmajah}{2456}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ عَبْدِ الْعَزِيزِ بْنِ جُرَيْجٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ لَمَّا سَمِعَ إِكْثَارَ النَّاسِ، فِي كِرَاءِ الأَرْضِ قَالَ سُبْحَانَ اللَّهِ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ مَنَحَهَا أَحَدُكُمْ أَخَاهُ ‏"‏ ‏.‏ وَلَمْ يَنْهَ عَنْ كِرَائِهَا ‏.‏\hadithno{2456}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that he heard that people were leasing out land more. He said:“Subhan-Allah, the Messenger of Allah (ﷺ) said: 'Why does not one of you lend it to his brother?' But he did not forbid leasing it out.' ”}}
\hadithdefcmd{ibnmajah}{2457}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَمْنَحَ أَحَدُكُمْ أَخَاهُ أَرْضَهُ خَيْرٌ لَهُ مِنْ أَنْ يَأْخُذَ عَلَيْهَا كَذَا وَكَذَا ‏"‏ ‏.‏ لِشَىْءٍ مَعْلُومٍ ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ هُوَ الْحَقْلُ وَهُوَ بِلِسَانِ الأَنْصَارِ الْمُحَاقَلَةُ ‏.‏\hadithno{2457}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) said:“If one of you were to lend his brother his land, it would be better for him than taking such and such rent for it.”}}
\hadithdefcmd{ibnmajah}{2458}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ حَنْظَلَةَ بْنِ قَيْسٍ، قَالَ سَأَلْتُ رَافِعَ بْنَ خَدِيجٍ قَالَ كُنَّا نُكْرِي الأَرْضَ عَلَى أَنَّ لَكَ مَا أَخْرَجَتْ هَذِهِ وَلِي مَا أَخْرَجَتْ هَذِهِ فَنُهِينَا أَنْ نُكْرِيَهَا بِمَا أَخْرَجَتْ وَلَمْ نُنْهَ أَنْ نُكْرِيَ الأَرْضَ بِالْوَرِقِ ‏.‏\hadithno{2458}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hazalah bin Qais said:“I asked Rafi' bin Khadij and he said: 'We used to lease out land on the basis that you would have what is produced by this piece of land, and I would have what is produced by this (other) piece of land, and we were forbidden to lease it out on the basis of crop-sharing but he did not forbid us to rent out land for silver.”}}
\hadithdefcmd{ibnmajah}{2459}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي أَبُو النَّجَاشِيِّ، أَنَّهُ سَمِعَ رَافِعَ بْنَ خَدِيجٍ، يُحَدِّثُ عَنْ عَمِّهِ، ظُهَيْرٍ قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَمْرٍ كَانَ لَنَا رَافِقًا ‏.‏ فَقُلْتُ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَهُوَ حَقٌّ ‏.‏ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَصْنَعُونَ بِمَحَاقِلِكُمْ ‏"‏ ‏.‏ قُلْنَا نُؤَاجِرُهَا عَلَى الثُّلُثِ وَالرُّبُعِ وَالأَوْسُقِ مِنَ الْبُرِّ وَالشَّعِيرِ ‏.‏ فَقَالَ ‏"‏ فَلاَ تَفْعَلُوا ازْرَعُوهَا أَوْ أَزْرِعُوهَا ‏"‏ ‏.‏\hadithno{2459}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Rafi'bin Khadi'j narrated that his paternal uncle Zuhair said:“The Messenger of Allah (ﷺ) forbade us from doing something that was convenient for us.” I said: “What the Messenger of Allah (ﷺ) said is true.” He said that the Messenger of Allah (ﷺ) said: “What do you with your farms?” We said: “We rent them out for one third or one quarter of their yield, and a certain amount of wheat and barley.” He said: “Do not do that; cultivate them or let others cultivate them.”}}
\hadithdefcmd{ibnmajah}{2460}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا الثَّوْرِيُّ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ أُسَيْدِ بْنِ ظُهَيْرٍ ابْنِ أَخِي، رَافِعِ بْنِ خَدِيجٍ عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ كَانَ أَحَدُنَا إِذَا اسْتَغْنَى عَنْ أَرْضِهِ، أَعْطَاهَا بِالثُّلُثِ وَالرُّبُعِ وَالنِّصْفِ وَاشْتَرَطَ ثَلاَثَةَ جَدَاوِلَ وَالْقُصَارَةَ وَمَا سَقَى الرَّبِيعُ وَكَانَ الْعَيْشُ إِذْ ذَاكَ شَدِيدًا وَكَانَ يَعْمَلُ فِيهَا بِالْحَدِيدِ وَبِمَا شَاءَ اللَّهُ وَيُصِيبُ مِنْهَا مَنْفَعَةً فَأَتَانَا رَافِعُ بْنُ خَدِيجٍ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَاكُمْ عَنْ أَمْرٍ كَانَ لَكُمْ نَافِعًا وَطَاعَةُ اللَّهِ وَطَاعَةُ رَسُولِهِ أَنْفَعُ لَكُمْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَاكُمْ عَنِ الْحَقْلِ وَيَقُولُ ‏ "‏ مَنِ اسْتَغْنَى عَنْ أَرْضِهِ فَلْيَمْنَحْهَا أَخَاهُ أَوْ لِيَدَعْ ‏"‏ ‏.‏\hadithno{2460}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Usaid bin Zuhair, the paternal nephew of Rafi' bin Khdij, that Rafi' bin Khadij said:“If one of us did not need his land, he would give it (to someone else to cultivate) in return for one third, or one half of the yield , and he would stipulate (that the should receive) the produce grows on the banks of three streams, and the grains that remain in the ear after threshing, and the produce irrigated by a stream. Life at that time was hard, and he would work (the land) with iron and whatever Allah (SWT) willed, and he would benefit from it. Then Rafi bin Khadij came to us and said: ‘The Messenger of Allah (ﷺ) forbade you to do something that may seem beneficial to you, but obedience to Allah and obedience to His Messenger are more beneficial for you. The Messenger of Allah (ﷺ) forbade Haq for you, and he said: “Whoever has no need of his land, let him give it to his brother (to cultivate) or let him leave it (uncultivated).”}}
\hadithdefcmd{ibnmajah}{2461}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِسْحَاقَ، حَدَّثَنِي أَبُو عُبَيْدَةَ بْنُ مُحَمَّدِ بْنِ عَمَّارِ بْنِ يَاسِرٍ، عَنِ الْوَلِيدِ بْنِ أَبِي الْوَلِيدِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ قَالَ زَيْدُ بْنُ ثَابِتٍ يَغْفِرُ اللَّهُ لِرَافِعِ بْنِ خَدِيجٍ أَنَا وَاللَّهِ، أَعْلَمُ بِالْحَدِيثِ مِنْهُ إِنَّمَا أَتَى رَجُلاَنِ النَّبِيَّ صلى الله عليه وسلم وَقَدِ اقْتَتَلاَ فَقَالَ ‏"‏ إِنْ كَانَ هَذَا شَأْنَكُمْ فَلاَ تُكْرُوا الْمَزَارِعَ ‏"‏ ‏.‏ قَالَ فَسَمِعَ رَافِعُ بْنُ خَدِيجٍ قَوْلَهُ ‏"‏ فَلاَ تُكْرُوا الْمَزَارِعَ ‏"‏ ‏.‏\hadithno{2461}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Zaid bin Thabit said:“May Allah (SWT) forgive Rafi' bin Khadij. By Allah (SWT)! I have more knowledge of Ahadith than he does. Two men who had quarreled came to the Prophet (ﷺ) and he said: 'If this is your situation, do not lease farms,' and what Rafi' bin khadij heard was 'Do not lease farms.' ”}}
\hadithdefcmd{ibnmajah}{2462}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ قُلْتُ لِطَاوُسٍ يَا أَبَا عَبْدِ الرَّحْمَنِ لَوْ تَرَكْتَ هَذِهِ الْمُخَابَرَةَ فَإِنَّهُمْ يَزْعُمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهُ ‏.‏ فَقَالَ أَىْ عَمْرُو إِنِّي أُعِينُهُمْ وَأُعْطِيهِمْ وَإِنَّ مُعَاذَ بْنَ جَبَلٍ أَخَذَ النَّاسَ عَلَيْهَا عِنْدَنَا وَإِنَّ أَعْلَمَهُمْ - يَعْنِي ابْنَ عَبَّاسٍ - أَخْبَرَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَنْهَ عَنْهَا وَلَكِنْ قَالَ ‏ "‏ لأَنْ يَمْنَحَ أَحَدُكُمْ أَخَاهُ خَيْرٌ لَهُ مِنْ أَنْ يَأْخُذَ عَلَيْهَا أَجْرًا مَعْلُومًا ‏"‏ ‏.‏\hadithno{2462}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Amr bin Dinar said:I said to Tawus: “O Abu 'Abdur-Rahman, why do you not give up this Mukhabarah because they claim that the Messenger of Allah (ﷺ) forbade it.” He said: “O 'Amr, I help them by taking their land and cultivating it, and giving them something in return, and Mu`adh bin Jabal allowed people here to do that. The most knowledgeable of them - meaning Ibn`Abbas - told me that the Messenger of Allah (ﷺ) did not forbid it, rather he said: 'For one you to give (land) to his brother is better than if he were to take a set amount in rent for it.'”}}
\hadithdefcmd{ibnmajah}{2463}{حَدَّثَنَا أَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ خَالِدٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، أَنَّ مُعَاذَ بْنَ جَبَلٍ، أَكْرَى الأَرْضَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ عَلَى الثُّلُثِ وَالرُّبُعِ فَهُوَ يَعْمَلُ بِهِ إِلَى يَوْمِكَ هَذَا ‏.‏\hadithno{2463}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Tawus that :Mu`adh bin Jabl leased some land during the time of the Messenger of Allah (ﷺ), Abu Bakr, 'Umar and 'Uthmah, in return for one third or one fourth (of the yield), and he was still doing that until this day of yours}}
\hadithdefcmd{ibnmajah}{2465}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ يَعْلَى بْنِ حَكِيمٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ كُنَّا نُحَاقِلُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَزَعَمَ أَنَّ بَعْضَ عُمُومَتِهِ أَتَاهُمْ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلاَ يُكْرِيهَا بِطَعَامٍ مُسَمًّى ‏"‏ ‏.‏\hadithno{2465}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Rafi` bin khadij said:We used to give land in return for food at the time of the Messenger of Allah (ﷺ), and some of my paternal uncles came to them and said: “The Messenger of Allah (ﷺ) said: 'Whoever has land, he should not rent it out for a set amount of food.”}}
\hadithdefcmd{ibnmajah}{2466}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَطَاءٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ زَرَعَ فِي أَرْضِ قَوْمٍ بِغَيْرِ إِذْنِهِمْ فَلَيْسَ لَهُ مِنَ الزَّرْعِ شَىْءٌ وَتُرَدُّ عَلَيْهِ نَفَقَتُهُ ‏"‏ ‏.‏\hadithno{2466}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Rafi` bin Khadij said:“The Messenger of Allah (ﷺ) said: 'Whoever cultivates people`s land without their permission, he has no right to any produce, but he should be recompensed for his expenditure.' ”}}
\hadithdefcmd{ibnmajah}{2467}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالُوا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَامَلَ أَهْلَ خَيْبَرَ بِالشَّطْرِ مِمَّا يَخْرُجُ مِنْ ثَمَرٍ أَوْ زَرْعٍ ‏.‏\hadithno{2467}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn `Umar that :the Messenger of Allah (ﷺ) entered into a contract with the people of Khaibar for one half of the fruits or crops yielded}}
\hadithdefcmd{ibnmajah}{2468}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ تَوْبَةَ، حَدَّثَنَا هُشَيْمٌ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَى خَيْبَرَ أَهْلَهَا عَلَى النِّصْفِ نَخْلُهَا وَأَرْضُهَا ‏.‏\hadithno{2468}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“When the Messenger of Allah (ﷺ) gave Khaibar to its people in return of its palm trees and land}}
\hadithdefcmd{ibnmajah}{2469}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ مُسْلِمٍ الأَعْوَرِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا افْتَتَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ أَعْطَاهَا عَلَى النِّصْفِ ‏.‏\hadithno{2469}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“When the Messenger of Allah (ﷺ) conquered Khaibar, he gave it (to its people) in return for half (of its yield).”}}
\hadithdefcmd{ibnmajah}{2470}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكٍ، أَنَّهُ سَمِعَ مُوسَى بْنَ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ مَرَرْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي نَخْلٍ فَرَأَى قَوْمًا يُلَقِّحُونَ النَّخْلَ فَقَالَ ‏"‏ مَا يَصْنَعُ هَؤُلاَءِ ‏"‏ ‏.‏ قَالُوا يَأْخُذُونَ مِنَ الذَّكَرِ فَيَجْعَلُونَهُ فِي الأُنْثَى ‏.‏ قَالَ ‏"‏ مَا أَظُنُّ ذَاكَ يُغْنِي شَيْئًا ‏"‏ ‏.‏ فَبَلَغَهُمْ فَتَرَكُوهُ وَنَزَلُوا عَنْهَا فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّمَا هُوَ ظَنٌّ إِنْ كَانَ يُغْنِي شَيْئًا فَاصْنَعُوهُ فَإِنَّمَا أَنَا بَشَرٌ مِثْلُكُمْ وَإِنَّ الظَّنَّ يُخْطِئُ وَيُصِيبُ وَلَكِنْ مَا قُلْتُ لَكُمْ قَالَ اللَّهُ فَلَنْ أَكْذِبَ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{2470}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Simak that the heard Musa bin Talhah bin `Ubaidullah narrating that his father said:“I passed by some palm trees with the Messenger of Allah (ﷺ) and he saw some people pollinating the trees. He said: 'What are these people doing?' They said: 'They are taking something from the male part (of the plant) and putting it in the female part.' He said: 'I do not think that this will do any good.' News of that reached them, so they stopped doing it, and their yield declined. News of that reached the Prophet (ﷺ) and he said: 'That was only my thought. If it will do any good, then do it. I am only a human being like you, and what I think may be right or wrong. But When I tell you: “Allah (SWT) says,” I will never tell lies about Allah (SWT).' ”}}
\hadithdefcmd{ibnmajah}{2471}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، وَهِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَمِعَ أَصْوَاتًا ‏.‏ فَقَالَ ‏"‏ مَا هَذَا الصَّوْتُ ‏"‏ ‏.‏ قَالُوا النَّخْلُ يُؤَبِّرُونَهُ فَقَالَ ‏"‏ لَوْ لَمْ يَفْعَلُوا لَصَلَحَ ‏"‏ ‏.‏ فَلَمْ يُؤَبِّرُوا عَامَئِذٍ فَصَارَ شِيصًا فَذَكَرُوا لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنْ كَانَ شَيْئًا مِنْ أَمْرِ دُنْيَاكُمْ فَشَأْنَكُمْ بِهِ وَإِنْ كَانَ شَيْئًا مِنْ أُمُورِ دِينِكُمْ فَإِلَىَّ ‏"‏ ‏.‏\hadithno{2471}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aisha that the Prophet (ﷺ) heard some sounds and said:“What is this noise?” They said: “Palm trees that are being pollinated.” He said: “If they did not do that it would be better.” So they did not pollinate them that year, and the dates did not mature properly. they mentioned that to the Prophet (ﷺ) and he said: “If it is one of the matters of your religion, then refer to me.”}}
\hadithdefcmd{ibnmajah}{2472}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ خِرَاشِ بْنِ حَوْشَبٍ الشَّيْبَانِيُّ، عَنِ الْعَوَّامِ بْنِ حَوْشَبٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُسْلِمُونَ شُرَكَاءُ فِي ثَلاَثٍ فِي الْمَاءِ وَالْكَلإِ وَالنَّارِ وَثَمَنُهُ حَرَامٌ ‏"‏ ‏.‏ قَالَ أَبُو سَعِيدٍ يَعْنِي الْمَاءَ الْجَارِيَ ‏.‏\hadithno{2472}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) said:“The Muslims are partners in three things: water, pasture and fire, and their price is unlawful.”}}
\hadithdefcmd{ibnmajah}{2473}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثٌ لاَ يُمْنَعْنَ الْمَاءُ وَالْكَلأُ وَالنَّارُ ‏"‏ ‏.‏\hadithno{2473}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Three things cannot be denied to anyone: water, pasture and fire.”}}
\hadithdefcmd{ibnmajah}{2474}{حَدَّثَنَا عَمَّارُ بْنُ خَالِدٍ الْوَاسِطِيُّ، حَدَّثَنَا عَلِيُّ بْنُ غُرَابٍ، عَنْ زُهَيْرِ بْنِ مَرْزُوقٍ، عَنْ عَلِيِّ بْنِ زَيْدِ بْنِ جُدْعَانَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ يَا رَسُولَ اللَّهِ مَا الشَّىْءُ الَّذِي لاَ يَحِلُّ مَنْعُهُ قَالَ الْمَاءُ وَالْمِلْحُ وَالنَّارُ ‏"‏ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ هَذَا الْمَاءُ قَدْ عَرَفْنَاهُ فَمَا بَالُ الْمِلْحِ وَالنَّارِ قَالَ ‏"‏ يَا حُمَيْرَاءُ مَنْ أَعْطَى نَارًا فَكَأَنَّمَا تَصَدَّقَ بِجَمِيعِ مَا أَنْضَجَتْ تِلْكَ النَّارُ وَمَنْ أَعْطَى مِلْحًا ‏.‏ فَكَأَنَّمَا تَصَدَّقَ بِجَمِيعِ مَا طَيَّبَ ذَلِكَ الْمِلْحُ وَمَنْ سَقَى مُسْلِمًا شَرْبَةً مِنْ مَاءٍ حَيْثُ يُوجَدُ الْمَاءُ فَكَأَنَّمَا أَعْتَقَ رَقَبَةً وَمَنْ سَقَى مُسْلِمًا شَرْبَةً مِنْ مَاءٍ حَيْثُ لاَ يُوجَدُ الْمَاءُ فَكَأَنَّمَا أَحْيَاهَا ‏"‏ ‏.‏\hadithno{2474}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:“O Messenger of Allah (ﷺ), what are the things which are not permissible to withhold?” He said: “Water, salt and fire.” She said: “I said: 'O Messenger of Allah (ﷺ), we know what water is, but what about salt and fire?” He said: “O Humaira', whoever gives fire (to another), it is as if he has given in charity all the food that is cooked on that fire. And whoever gives salt, it is as if he has given in charity all that the salt makes good. And whoever gives a Muslim water to drink when water is available, it is as if he freed a slave; and whoever gives a Muslim water to drink when there is no water available, it is as if he brought him back to life.”}}
\hadithdefcmd{ibnmajah}{2475}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا فَرَجُ بْنُ سَعِيدِ بْنِ عَلْقَمَةَ بْنِ سَعِيدِ بْنِ أَبْيَضَ بْنِ حَمَّالٍ، حَدَّثَنِي عَمِّي، ثَابِتُ بْنُ سَعِيدِ بْنِ أَبْيَضَ بْنِ حَمَّالٍ عَنْ أَبِيهِ، سَعِيدٍ عَنْ أَبِيهِ، أَبْيَضَ بْنِ حَمَّالٍ ‏.‏ أَنَّهُ اسْتَقْطَعَ الْمِلْحَ الَّذِي يُقَالُ لَهُ مِلْحُ سَدِّ مَأْرِبٍ ‏.‏ فَأَقْطَعَهُ لَهُ ثُمَّ إِنَّ الأَقْرَعَ بْنَ حَابِسٍ التَّمِيمِيَّ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ وَرَدْتُ الْمِلْحَ فِي الْجَاهِلِيَّةِ وَهُوَ بِأَرْضٍ لَيْسَ بِهَا مَاءٌ وَمَنْ وَرَدَهُ أَخَذَهُ وَهُوَ مِثْلُ الْمَاءِ الْعِدِّ ‏.‏ فَاسْتَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبْيَضَ بْنَ حَمَّالٍ فِي قَطِيعَتِهِ فِي الْمِلْحِ ‏.‏ فَقَالَ قَدْ أَقَلْتُكَ مِنْهُ عَلَى أَنْ تَجْعَلَهُ مِنِّي صَدَقَةً ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ مِنْكَ صَدَقَةٌ وَهُوَ مِثْلُ الْمَاءِ الْعِدِّ مَنْ وَرَدَهُ أَخَذَهُ ‏"‏ ‏.‏ قَالَ فَرَجٌ وَهُوَ الْيَوْمَ عَلَى ذَلِكَ مَنْ وَرَدَهُ أَخَذَهُ ‏.‏ قَالَ فَقَطَعَ لَهُ النَّبِيُّ صلى الله عليه وسلم أَرْضًا وَنَخْلاً بِالْجُرْفِ جُرْفِ مُرَادٍ مَكَانَهُ حِينَ أَقَالَهُ مِنْهُ ‏.‏\hadithno{2475}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abyad bin Hammal:That he asked for a salt flat called the Ma'rib Dam to be given to him, and it was given to him. Then Aqra bin Habis At-Tamimi came to the Messenger of Allah (ﷺ) and said: “O Messenger of Allah (ﷺ), I used to come to the salt flat during the Ignorance period and it was in a land in which there was no water, and whoever came to it took from it. It was (plentiful) like flowing water.” So the Messenger of Allah (ﷺ) asked Abyad bin Hammal to give back his share of the salt flat. He said: “I give it to you on the basis that you make it charity given by me.” The Messenger of Allah said: “It is a charity from you, and it is like flowing water, whoever comes to it may take from it.”(One of the narrators) Faraj said: “That is how it is today, whoever comes to it takes from it.” He said: “The Prophet (ﷺ) gave him land and palm trees in Jurf Murad instead, when he took back the salt flat from him.”}}
\hadithdefcmd{ibnmajah}{2478}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْنَعْ أَحَدُكُمْ فَضْلَ مَاءٍ لِيَمْنَعَ بِهِ الْكَلأَ ‏"‏ ‏.‏\hadithno{2478}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“No one of you should withhold surplus water from common pastureland.”}}
\hadithdefcmd{ibnmajah}{2479}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ حَارِثَةَ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُمْنَعُ فَضْلُ الْمَاءِ وَلاَ يُمْنَعُ نَقْعُ الْبِئْرِ ‏"‏ ‏.‏\hadithno{2479}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Aishah that the Messenger of Allah (ﷺ) said:“Surplus water should not be withheld, and neither should surplus water from a well}}
\hadithdefcmd{ibnmajah}{2480}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ خَاصَمَ الزُّبَيْرَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي شِرَاجِ الْحَرَّةِ الَّتِي يَسْقُونَ بِهَا النَّخْلَ فَقَالَ الأَنْصَارِيُّ سَرِّحِ الْمَاءَ يَمُرَّ ‏.‏ فَأَبَى عَلَيْهِ فَاخْتَصَمَا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ أَرْسِلِ الْمَاءَ إِلَى جَارِكَ ‏"‏ ‏.‏ فَغَضِبَ الأَنْصَارِيُّ فَقَالَ يَا رَسُولَ اللَّهِ أَنْ كَانَ ابْنَ عَمَّتِكَ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ يَا زُبَيْرُ اسْقِ ثُمَّ احْبِسِ الْمَاءَ حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏ ‏.‏ قَالَ فَقَالَ الزُّبَيْرُ وَاللَّهِ إِنِّي لأَحْسَبُ هَذِهِ الآيَةَ أُنْزِلَتْ فِي ذَلِكَ ‏\{‏فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ ثُمَّ لاَ يَجِدُوا فِي أَنْفُسِهِمْ حَرَجًا مِمَّا قَضَيْتَ وَيُسَلِّمُوا تَسْلِيمًا‏\}‏‏.‏\hadithno{2480}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{It was narrated from 'Abdullah bin Zubair that :a man from among the Ansar had a dispute with Zubair in the presence of the Messenger of Allah (ﷺ) concerning the streams of the Harrah with which he irrigated his palm trees. The Ansari said: “Let the water flow,” but he refused. So they referred their dispute to the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said: “Irrigate (your trees) O Zubair, then let the water flow to your neighbor.” The Ansari became angry and said: “O Messenger of Allah (ﷺ), is it because he is your cousin (son of your paternal aunt)?” The expression of the Messenger of Allah (ﷺ) changed, then he said: “O Zubair, irrigate (your trees) then retain the water until it reaches the walls.” Zubair said: “I think this Verse was revealed concerning that: “But no, by your Lord, they make you (O Muhammad) judge in all disputes between them, and find in themselves no resistance against your decisions, and accept (them) with full submission [1].'” (Sahih) [1] An-Nisa}}
\hadithdefcmd{ibnmajah}{2481}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا زَكَرِيَّا بْنُ مَنْظُورِ بْنِ ثَعْلَبَةَ بْنِ أَبِي مَالِكٍ، حَدَّثَنِي مُحَمَّدُ بْنُ عُقْبَةَ بْنِ أَبِي مَالِكٍ، عَنْ عَمِّهِ، ثَعْلَبَةَ بْنِ أَبِي مَالِكٍ قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَيْلِ مَهْزُورٍ الأَعْلَى فَوْقَ الأَسْفَلِ يَسْقِي الأَعْلَى إِلَى الْكَعْبَيْنِ ثُمَّ يُرْسِلُ إِلَى مَنْ هُوَ أَسْفَلُ مِنْهُ ‏.‏\hadithno{2481}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Tha'labah bin Abu Malik said:“The Messenger of Allah (ﷺ) ruled concerning the stream of Mahzur that the higher ground took precedence over the lower, so the higher ground should be irrigated until the water reached the ankles, then it should be released to those who were lower}}
\hadithdefcmd{ibnmajah}{2482}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي أَبِي، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي سَيْلِ مَهْزُورٍ أَنْ يُمْسِكَ حَتَّى يَبْلُغَ الْكَعْبَيْنِ ثُمَّ يُرْسِلَ الْمَاءَ ‏.‏\hadithno{2482}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu`aib, from his father, from his grandfather, that :the Messenger of Allah (ﷺ) ruled concerning the stream of Mahzur that the water should be retained until it reached the ankles, then released}}
\hadithdefcmd{ibnmajah}{2483}{حَدَّثَنَا أَبُو الْمُغَلِّسِ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ إِسْحَاقَ بْنِ يَحْيَى بْنِ الْوَلِيدِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي شُرْبِ النَّخْلِ مِنَ السَّيْلِ أَنَّ الأَعْلَى فَالأَعْلَى يَشْرَبُ قَبْلَ الأَسْفَلِ وَيُتْرَكُ الْمَاءُ إِلَى الْكَعْبَيْنِ ثُمَّ يُرْسَلُ الْمَاءُ إِلَى الأَسْفَلِ الَّذِي يَلِيهِ وَكَذَلِكَ حَتَّى تَنْقَضِيَ الْحَوَائِطُ أَوْ يَفْنَى الْمَاءُ ‏.‏\hadithno{2483}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Ubadah bin Samit that :the Messenger of Allah (ﷺ) ruled concerning the irrigation of palm trees from streams, that the higher ground should be irrigated before the lower, and that the water should be allowed to reach the ankles, then released to flow the nearest lower ground, and so on, until all the fields were watered or until the water ran out}}
\hadithdefcmd{ibnmajah}{2484}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، أَنْبَأَنَا أَبُو الْجَعْدِ عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ، عَنْ كَثِيرِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ الْمُزَنِيِّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُبْدَأُ بِالْخَيْلِ يَوْمَ وِرْدِهَا ‏"‏ ‏.‏\hadithno{2484}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Kathir bin 'Abdullah bin 'Amr bin 'Awf Al-Muzani, from his father, that his grandfather said:“The Messenger of Allah (ﷺ) said: 'Start with the horses on the day that you bring (the animals to drink).' ”}}
\hadithdefcmd{ibnmajah}{2485}{حَدَّثَنَا الْعَبَّاسُ بْنُ جَعْفَرٍ، حَدَّثَنَا مُوسَى بْنُ دَاوُدَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمٍ الطَّائِفِيُّ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ قَسْمٍ قُسِمَ فِي الْجَاهِلِيَّةِ فَهُوَ عَلَى مَا قُسِمَ وَكُلُّ قَسْمٍ أَدْرَكَهُ الإِسْلاَمُ فَهُوَ عَلَى قَسْمِ الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{2485}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn `Abbas that the Messenger of Allah (ﷺ) said:“Every division that was allocated according to (the rules of) the Ignorance days, stands as it is, and every division that was allocated according to (the rules of) Islam, stands according to the rules of Islam.”}}
\hadithdefcmd{ibnmajah}{2486}{حَدَّثَنَا الْوَلِيدُ بْنُ عَمْرِو بْنِ سُكَيْنٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُثَنَّى، ح وَحَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ الْمَكِّيُّ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَفَرَ بِئْرًا فَلَهُ أَرْبَعُونَ ذِرَاعًا عَطَنًا لِمَاشِيَتِهِ ‏"‏ ‏.‏\hadithno{2486}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Mughaffal that the Prophet (ﷺ) said:“Whoever digs a well, is entitled to forty forearms' length surrounding it is as a resting place for his flocks.”}}
\hadithdefcmd{ibnmajah}{2487}{حَدَّثَنَا سَهْلُ بْنُ أَبِي الصُّغْدِيِّ، حَدَّثَنَا مَنْصُورُ بْنُ صُقَيْرٍ، حَدَّثَنَا ثَابِتُ بْنُ مُحَمَّدٍ، عَنْ نَافِعٍ أَبِي غَالِبٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حَرِيمُ الْبِئْرِ مَدُّ رِشَائِهَا ‏"‏ ‏.‏\hadithno{2487}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Messenger of Allah (ﷺ) said:“The land around a well (that is considered to be part of it) is the length of the well rope (in all directions).”}}
\hadithdefcmd{ibnmajah}{2488}{حَدَّثَنَا عَبْدُ رَبِّهِ بْنُ خَالِدٍ النُّمَيْرِيُّ أَبُو الْمُغَلِّسِ، حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، أَخْبَرَنِي إِسْحَاقُ بْنُ يَحْيَى بْنِ الْوَلِيدِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي النَّخْلَةِ وَالنَّخْلَتَيْنِ وَالثَّلاَثَةِ لِلرَّجُلِ فِي النَّخْلِ فَيَخْتَلِفُونَ فِي حُقُوقِ ذَلِكَ فَقَضَى أَنَّ لِكُلِّ نَخْلَةٍ مِنْ أُولَئِكَ مِنَ الأَرْضِ مَبْلَغُ جَرِيدِهَا حَرِيمٌ لَهَا ‏.‏\hadithno{2488}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ubadah bin Samit that :the Messenger of Allah (ﷺ) ruled concerning one, two or three date palms belonging to a man among other palm trees - when they differ concerning entitlement to the surrounding land. He ruled that the land around each of those trees, as far as their leaves reach, measured from the bottom of the tree, belongs to the owner of the tree}}
\hadithdefcmd{ibnmajah}{2489}{حَدَّثَنَا سَهْلُ بْنُ أَبِي الصُّغْدِيِّ، حَدَّثَنَا مَنْصُورُ بْنُ صُقَيْرٍ، حَدَّثَنَا ثَابِتُ بْنُ مُحَمَّدٍ الْعَبْدِيُّ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حَرِيمُ النَّخْلَةِ مَدُّ جَرِيدِهَا ‏"‏ ‏.‏\hadithno{2489}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah Said:“The land around a date-palm tree, as far as its branches reach, belongs to the owner of the tree.”}}
\hadithdefcmd{ibnmajah}{2490}{\hadithno{2490}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan}\hadithtrans{}}
\hadithdefcmd{ibnmajah}{2491}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَعَمْرُو بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا أَبُو مَالِكٍ النَّخَعِيُّ، عَنْ يُوسُفَ بْنِ مَيْمُونٍ، عَنْ أَبِي عُبَيْدَةَ بْنِ حُذَيْفَةَ، عَنْ أَبِيهِ، حُذَيْفَةَ بْنِ الْيَمَانِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَاعَ دَارًا وَلَمْ يَجْعَلْ ثَمَنَهَا فِي مِثْلِهَا لَمْ يُبَارَكْ لَهُ فِيهَا ‏"‏ ‏.‏\hadithno{2491}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hudhaifah bin Yaman that the Messenger of Allah (ﷺ) said:“Whoever sells a house and does not use the money for something similar, will not to be blessed therein.' ”}}
